@@ -1,4 +1,4 @@
-import requests
+import requests, json
 import logging
 
 logging.basicConfig(level=logging.INFO)
@@ -9,12 +9,14 @@ class NotAvailableOrderBook(object):
 
 
 class RamzinexPublic:
-    def __init__(self, verbose=0):
+    def __init__(self, verbose=0, timeout=100):
         """
 
         :param verbose: 0 no log, 1 log responses only, 2 log responses and messages
         """
         self.verbose = verbose
+        self.timeout = timeout
+        self.resp = None
         self.url = 'https://ramzinex.com/exchange/api/v1.0/exchange'
         self.auth = None
         self.session = requests.Session()
@@ -53,8 +55,12 @@ class RamzinexPublic:
         """
         self.log_info(f'Sending {message} to server', base_log_level + 2)
         url = message
+        # try:
         self.resp = self.session.request(method, url, params=params, data=data,
-                                         headers=self.auth, timeout=30)
+                                         headers=self.auth, timeout=self.timeout)
+        # except requests.exceptions.ReadTimeout as e:
+        #     self.resp = False
+        #     return False
         self.log_info(f'received response: {self.resp.text}', base_log_level + 1)
         if self.resp.status_code == 200:
             self.resp = self.resp.json()
@@ -93,12 +99,14 @@ class RamzinexPublic:
 
     def _buys_book(self, pair_id):
         url_new = self.url.replace('ramzinex.com', 'publicapi.ramzinex.com')
+        # url_new = self.url
         message = f'{url_new}/orderbooks/{pair_id}/buys'
         self._tear_down_request('_buys_book', message, base_log_level=2)
         return self.resp
 
     def _sells_book(self, pair_id):
         url_new = self.url.replace('ramzinex.com', 'publicapi.ramzinex.com')
+        # url_new = self.url
         message = f'{url_new}/orderbooks/{pair_id}/sells'
         self._tear_down_request('_sells_book', message, base_log_level=2)
         return self.resp
@@ -231,11 +239,10 @@ class RamzinexPrivate(RamzinexPublic):
         return the status of specified orders
 
         :param limit: integer, number of requested orders
-        :param offset: integer, offset in the return orders
         :param types: array of integer, 1: limit, 2: market
         :param markets: array of strings, market pairs
         :param currencies: array of strings, 'btc', 'irr', ...
-        :param states: arrays of integer, 1: open, 2: canceled, 3: filled
+        :param states: arrays of integer, 1: open, 3: 100% filled, 4: canceled
         :param is_buy: boolean
         :return:
         """
@@ -249,17 +256,44 @@ class RamzinexPrivate(RamzinexPublic):
             'is_buy': is_buy,
         }
         message = f"{self.url}/users/me/orders2"
-        self._tear_down_request('get_user_order', message, params=param, method='post')
+        self._tear_down_request('get_user_order', message, data=json.dumps(param), method='post')
         return self.resp
 
-    def cancel_all_orders(self):
-        resp = self.get_user_order(10, 2, [], [], [], [], False)
-        if 'data' in resp:
-            open_orders = [data['id'] for data in resp['data'] if data['status_id'] == 1]
-            for order_id in open_orders:
-                self.cancel_order(order_id)
-                self.log_info(f'{order_id} is cancelled.', self.verbose)
-            return 1
-        else:
-            self.log_info('user order is not accessible.', self.verbose + 1)
-            return 0
\ No newline at end of file
+    # def cancel_all_orders(self):
+    #     """
+    #     Cancel the last 50 orders if they are open
+    #     :return:
+    #     """
+    #     resp = self.get_user_order(10, 2, [], [], [], [], False)
+    #     if 'data' in resp:
+    #         open_orders = [data['id'] for data in resp['data'] if data['status_id'] == 1]
+    #         for order_id in open_orders:
+    #             self.cancel_order(order_id)
+    #             self.log_info(f'{order_id} is cancelled.', self.verbose)
+    #         return 1
+    #     else:
+    #         self.log_info('user order is not accessible.', self.verbose + 1)
+    #         return 0
+
+    def currency_deposit_list(self, currency):
+        assert currency in self.currencies.keys(), f'invalid currency: {currency}'
+        message = f"{self.url}/users/me/funds/deposits/currency/{self.currencies[currency]['id']}"
+        self._tear_down_request('currency_deposit_list', message, method='get')
+        return self.resp
+
+    def withdraws_list(self):
+        message = f"{self.url}/users/me/funds/withdraws"
+        self._tear_down_request('withdraws_list', message, method='get')
+        return self.resp
+
+    def submit_withdraw_request(self, currency, param):
+        assert 'amount' in param, f'amount key is required in param input'
+        assert 'address' in param, f'address key is required in param input'
+        assert 'network_id' in param, f'network_id key is required in param input'
+        assert currency in self.currencies.keys(), f'invalid currency: {currency}'
+        param['currency_id'] = self.currencies[currency]['id']
+
+        param['no_tag'] = True if 'tag' in param else False
+        message = f"{self.url}/users/me/funds/withdraws/currency/{param['currency_id']}"
+        self._tear_down_request('submit_withdraw_request', message, data=json.dumps(param), method='post')
+        return self.resp
